package de.intevation.flys.artifacts.states.fixation;

import de.intevation.artifactdatabase.state.Facet;

import de.intevation.artifacts.CallContext;

import de.intevation.flys.artifacts.FLYSArtifact;
import de.intevation.flys.artifacts.FixationArtifactAccess;

import de.intevation.flys.artifacts.model.CalculationResult;
import de.intevation.flys.artifacts.model.DataFacet;
import de.intevation.flys.artifacts.model.FacetTypes;
import de.intevation.flys.artifacts.model.ReportFacet;

import de.intevation.flys.artifacts.model.fixings.FixCalculation;

import de.intevation.flys.artifacts.states.DefaultState;

import java.util.List;

import org.apache.log4j.Logger;

/**
 * @author <a href="mailto:raimund.renkert@intevation.de">Raimund Renkert</a>
 */
public class FixationCompute
extends      DefaultState
implements   FacetTypes
{

    /** The log used in this class. */
    private static Logger log = Logger.getLogger(FixationCompute.class);


    /**
     * The default constructor that initializes an empty State object.
     */
    public FixationCompute() {
    }

    @Override
    public Object computeAdvance(
        FLYSArtifact artifact,
        String       hash,
        CallContext  context,
        List<Facet>  facets,
        Object       old
    ) {
        log.debug("FixationCompute.computeAdvance");

        CalculationResult res;

        if (old instanceof CalculationResult) {
            res = (CalculationResult)old;
        }
        else {
            FixationArtifactAccess access =
                new FixationArtifactAccess(artifact);

            FixCalculation calc =
                new FixCalculation(access);

            res = calc.calculate();
        }

        if (facets == null) {
            return res;
        }

        if (res.getReport().hasProblems()) {
            facets.add(new ReportFacet(ComputeType.ADVANCE, hash, id));
        }
        facets.add(
            new DataFacet(CSV, "CSV data", ComputeType.ADVANCE, hash, id));

        return res;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :
